@@ -160,6 +160,14 @@ class CacheWorkspace:
         self.name = None
         self._mk_cache()
 
+    def cleanup(self) -> None:
+        '''release the allocated workspace.
+
+        Files will be deleted automatically one day after release.
+        '''
+        waitfor(self.ws.ws_release(self.id))
+        self.name = None
+
     def _mk_cache(self) -> str:
         '''Allocate a workspace on the cluster
 
@@ -172,40 +180,12 @@ class CacheWorkspace:
             self.expire_in_days), '-c', 'temporary_files')
         waitfor(proc, discard_output=False)
         out, _ = proc.communicate()
-        self.name = out.strip()
-
-    def cleanup(self) -> None:
-        '''release the allocated workspace.
-
-        Files will be deleted automatically one day after release.
-        '''
-        waitfor(self.ws.ws_release(self.id))
-        self.name = None
-
-
-class CacheWorkspaceContext(CacheWorkspace):
-    '''Context manager for a cache workspace
-    '''
-
-    def __init__(self, path_to_exe: str = '/usr/bin/',
-                 id: str = 'cache') -> None:
-        '''Create a context manager for a cache workspace.
-
-        Parameters
-        ----------
-        path_to_exe : str, optional
-            path to the ws_* executables, by default '/usr/bin/'
-        id : str, optional
-            id of the workspace to be used as cache, by default "cache"
-        '''
-        self.ws = Workspace(path_to_exe=path_to_exe)
-        self.id = id
-        self.expire_in_days = 1
-        self.name = None
+        self.name = out.strip().decode('utf-8')
 
     def __enter__(self) -> None:
         if self.name is None:
             self._mk_cache()
+        return self
 
     def __exit__(self, exception_type, exception_value, traceback) -> None:
         if self.name is not None:
